@@ -42,7 +42,7 @@ class ExportManager : public QObject
 
     private:
 
-    explicit ExportManager(QObject *parent = 0);
+    explicit ExportManager(QObject *parent = nullptr);
     virtual ~ExportManager();
 
     ExportManager(ExportManager const&) = delete;
@@ -63,7 +63,6 @@ class ExportManager : public QObject
     bool isFileExists(const QUrl &url) const;
     void setPixmap(const QPixmap &pixmap);
     QPixmap pixmap() const;
-    QString pixmapDataUri() const;
     void setWindowTitle(const QString &windowTitle);
     QString windowTitle() const;
     ImageGrabber::GrabMode grabMode() const;
@@ -83,7 +82,7 @@ class ExportManager : public QObject
     QUrl tempSave(const QString &mimetype = QStringLiteral("png"));
 
     void doSave(const QUrl &url = QUrl(), bool notify = false);
-    bool doSaveAs(QWidget *parentWindow = 0, bool notify = false);
+    bool doSaveAs(QWidget *parentWindow = nullptr, bool notify = false);
     void doCopyToClipboard();
     void doPrint(QPrinter *printer);
 
