@@ -172,6 +172,7 @@ void ExportMenu::loadPurposeMenu()
     // attach the menu
     QAction *purposeMenu = addMenu(mPurposeMenu);
     purposeMenu->setText(i18n("Share"));
+    purposeMenu->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
 
     // set up the callback signal
     connect(mPurposeMenu, &Purpose::Menu::finished, this, [this](const QJsonObject &output, int error, const QString &message) {
@@ -193,7 +194,7 @@ void ExportMenu::loadPurposeItems()
     }
 
     // updated image available, we lazily load it now
-    QString dataUri = ExportManager::instance()->pixmapDataUri();
+    QString dataUri = ExportManager::instance()->tempSave().toString();
     mUpdatedImageAvailable = false;
 
     mPurposeMenu->model()->setInputData(QJsonObject {
