@@ -24,6 +24,7 @@
 
 class QDialogButtonBox;
 class QLineEdit;
+class QComboBox;
 class KUrlRequester;
 
 class SaveOptionsPage : public SettingsPage
@@ -32,7 +33,7 @@ class SaveOptionsPage : public SettingsPage
 
     public:
 
-    explicit SaveOptionsPage(QWidget *parent = 0);
+    explicit SaveOptionsPage(QWidget *parent = nullptr);
 
     public slots:
 
@@ -48,6 +49,7 @@ class SaveOptionsPage : public SettingsPage
     QDialogButtonBox *mDialogButtonBox;
     QLineEdit        *mSaveNameFormat;
     KUrlRequester    *mUrlRequester;
+    QComboBox        *mSaveImageFormat;
 };
 
 #endif // SAVEOPTIONSPAGE_H
